﻿using System;
using System.IO;
using System.Text.RegularExpressions;

namespace PMCProjekt
{
    internal class Programm
    {
        static void Main(string[] args)
        {
            // Kundennummer eingeben
            Console.Write("Bitte geben Sie die Kundennummer ein (z.B. K2-002): ");
            string kundennummer = Console.ReadLine();

            // Datei einlesen
            string dateiPfad = "C:/Schule/PMC/import_yutani.csv";
            if (File.Exists(dateiPfad))
            {
                using (StreamReader sr = new StreamReader(dateiPfad))
                {
                    string zeile;
                    while ((zeile = sr.ReadLine()) != null)
                    {
                        // Werte aus der Zeile extrahieren
                        string[] werte = zeile.Split(',');
                        if (werte.Length >= 4)
                        {
                            string anrede = werte[0];
                            string vorname = werte[1];
                            string nachname = werte[2];
                            string geburtsdatum = werte[3];
                            string adresse = werte.Length > 4 ? werte[4] : null;
                            string plz = werte.Length > 5 ? werte[5] : null;
                            string stadt = werte.Length > 6 ? werte[6] : null;
                            string email = werte.Length > 7 ? werte[7] : null;
                            string telefonnummern = werte.Length > 8 ? werte[8] : null;

                            // Daten validieren und ungültige Daten protokollieren
                            if (!DatenValidieren(anrede, vorname, nachname, geburtsdatum, adresse, plz, stadt, email, telefonnummern))
                            {
                                ProtokolliereUngueltigeDaten(werte);
                                Console.WriteLine("Ungültige Daten: " + string.Join(",", werte));
                            }
                            else
                            {
                                Console.WriteLine("Gültige Daten: " + string.Join(",", werte));
                            }
                        }
                        else
                        {
                            // Protokolliere Zeilen mit zu wenigen Datenfeldern
                            ProtokolliereUngueltigeDaten(werte);
                            Console.WriteLine("Ungültige Daten (zu wenige Felder): " + string.Join(",", werte));
                        }
                    }
                }
            }
            else
            {
                Console.WriteLine("Datei nicht gefunden.");
            }
        }

        static bool DatenValidieren(string anrede, string vorname, string nachname, string geburtsdatum, string adresse, string plz, string stadt, string email, string telefonnummern)
        {
            bool istGueltig = true;

            // Geburtsdatum validieren
            if (!PrüfGeburtstag(geburtsdatum))
            {
                Console.WriteLine($"Ungültiges Geburtsdatum: {geburtsdatum}");
                istGueltig = false;
            }

            // E-Mail-Adresse validieren
            if (!string.IsNullOrEmpty(email) && !PrüfEmail(email))
            {
                Console.WriteLine($"Ungültige E-Mail-Adresse: {email}");
                istGueltig = false;
            }

            // Postleitzahl validieren
            if (!string.IsNullOrEmpty(plz) && !PrüfPLZ(plz))
            {
                Console.WriteLine($"Ungültige Postleitzahl: {plz}");
                istGueltig = false;
            }

            // Telefonnummern validieren
            if (!string.IsNullOrEmpty(telefonnummern))
            {
                string[] telefonNummern = telefonnummern.Split(';');
                foreach (var telefon in telefonNummern)
                {
                    if (!PrüfTelefon(telefon))
                    {
                        Console.WriteLine($"Ungültige Telefonnummer: {telefon}");
                        istGueltig = false;
                    }
                }
            }

            return istGueltig;
        }

        static bool PrüfGeburtstag(string geburtsdatum)
        {
            string pattern = @"^\d{4}\-\d{2}\-\d{2}$";
            return Regex.IsMatch(geburtsdatum, pattern);
        }

        static bool PrüfEmail(string email)
        {
            string pattern = @"^[a-z]+\.[a-z]+@[a-z]+\.[a-z]{2,}$";
            return Regex.IsMatch(email, pattern);
        }

        static bool PrüfPLZ(string plz)
        {
            string pattern = @"^[0-9]{5}$";
            return Regex.IsMatch(plz, pattern);
        }

        static bool PrüfTelefon(string telefon)
        {
            string pattern = @"^[0-9]{3,5}\s?[0-9]{4,10}$";
            return Regex.IsMatch(telefon, pattern);
        }

        static void ProtokolliereUngueltigeDaten(string[] daten)
        {
            string protokollPfad = "C:/Schule/PMC/ungueltige_Daten.csv";
            using (StreamWriter sw = new StreamWriter(protokollPfad, true))
            {
                sw.WriteLine(string.Join(",", daten));
            }
        }
    }
}
